%define _localstatedir /var/lib
%define site_lisp %{_datadir}/emacs/site-lisp
%define site_start_d %{site_lisp}/site-start.d

Summary:	GNU Emacs text editor with X11 support
Name:		emacs
Version:	29.4
Release:	%mkrel 5
License:	GPLv3+
Group:		Editors
URL:		https://www.gnu.org/software/emacs/

Source0:	https://ftp.gnu.org/gnu/emacs/emacs-%{version}.tar.xz
Source5:	emacs-config
Source9:	emacs-pgtk.desktop
Source10:	emacs.appdata.xml

# rhbz#713600
Patch2:		emacs-system-crypto-policies.patch
Patch4:		emacs-libdir-vs-systemd.patch

BuildRequires:	x11-server-common
BuildRequires:	pkgconfig(x11)
BuildRequires:	gcc
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libpng)
BuildRequires:	pkgconfig(libtiff-4)
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	giflib-devel
BuildRequires:	texinfo
BuildRequires:	pkgconfig(xpm)
BuildRequires:	pkgconfig(gtk+-3.0)
BuildRequires:	pkgconfig(ImageMagick)
BuildRequires:	pkgconfig(gnutls)
BuildRequires:	pkgconfig(harfbuzz)
BuildRequires:	pkgconfig(jansson)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(librsvg-2.0)
BuildRequires:	pkgconfig(libotf)
BuildRequires:	pkgconfig(m17n-flt)
BuildRequires:	pkgconfig(tree-sitter)
BuildRequires:	pkgconfig(webkit2gtk-4.1)
BuildRequires:	systemd-devel
BuildRequires:	gpm-devel
BuildRequires:	acl-devel

Requires(preun): update-alternatives
Requires(post):  update-alternatives

Requires:	%{name}-common = %{version}
Provides:	emacs = %{version}-%{release}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Provides:	emacs-gtk = %{version}-%{release}
Provides:	emacs-X11 = %{version}-%{release}

Recommends:	hunspell

%description
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with support for X Windows.

%package	el
Summary:	GNU Emacs Lisp source files
Group:		Editors
Requires:	%{name}-common = %{version}
BuildArch:	noarch

%description	el
The emacs-snapshot-el package contains the emacs elisp sources for
many of the elisp programs included with the main Emacs text editor
package.

You need to install this package only if you intend to modify any of
the Emacs packages or see some elisp examples.

%package	doc
Summary:	GNU Emacs documentation
Group:		Editors
Requires:	%{name}-common = %{version}
BuildArch:	noarch

%description	doc
Documentation for GNU Emacs.

%package	leim
Summary:	GNU Emacs Lisp code for international input methods
Group:		Editors
BuildArch:	noarch
Requires:	%{name}-common = %{version}

%description	leim
This package contains Emacs Lisp code for input methods for various
international character scripts.

%package	nox
Summary:	GNU Emacs text editor without support for X11
Group:		Editors
Requires:	%{name}-common = %{version}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Requires(preun): update-alternatives
Requires(post):  update-alternatives

%description	nox
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with no X Windows support for
running on a terminal.

%package	pgtk
Summary:	GNU Emacs text editor with support for Wayland only
Group:		Editors
Requires:	%{name}-common = %{version}
Provides:	emacs(bin) = %{version}-%{release}
Provides:	emacs-bin = %{version}-%{release}
Requires(preun): update-alternatives
Requires(post):  update-alternatives

%description	pgtk
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package provides an emacs binary with support for Wayland only.

%package	common
Summary:	Common files for GNU Emacs
Group:		Editors
Recommends:	enchant2

Provides:	gnus-emacs = 5.13
Provides:	emacs-cedet = 2.0
Provides:	emacs-speedbar = 1.0
Provides:	emacs-tramp = 2.4.5.27.2
Provides:	emacs-pcomplete = 21.1
Provides:	eshell-emacs = 2.4.2
Provides:	emacs-erc = %{version}

Conflicts:	emacs < 29.4-3
Conflicts:	emacs-pgtk < 29.4-3

%description	common
Emacs is a powerful, customizable, self-documenting, modeless text
editor. Emacs contains special code editing features, a scripting
language (elisp), and the capability to read mail, news, and more
without leaving the editor.

This package contains all of the common files needed by emacs-snapshot
emacs-snaphot-pgtk or emacs-snapshot-nox.

%prep
%autosetup -p1

perl -p -i -e 's/ctags/gctags/g' doc/man/etags.1

# Build against webkit2gtk-4.1
sed -i -e 's/webkit2gtk-4.0/webkit2gtk-4.1/g' configure.ac

%build
autoreconf -fi -I m4

export CFLAGS="%{build_cflags} -fno-zero-initialized-in-bss"

# Build binary without X support
mkdir -p build-nox
pushd build-nox
export CONFIGURE_TOP=..
  %configure --with-x=no --with-gpm --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Build pure GTK binary with Wayland only support
mkdir -p build-pgtk
pushd build-pgtk
  %configure --with-pgtk --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Build binary with X support
mkdir -p build-gtk
pushd build-gtk
  %configure --with-x-toolkit=gtk3 --with-xwidgets --with-cairo --with-tree-sitter
  %make_build bootstrap
  %make_build
popd

# Create macros.emacs RPM macro file
cat > macros.emacs << EOF
%%_emacs_version %{version}
%%_emacs_ev %{?epoch:%{epoch}:}%{version}
%%_emacs_evr %{?epoch:%{epoch}:}%{version}-%{release}
%%_emacs_sitelispdir %{site_lisp}
%%_emacs_sitestartdir %{site_start_d}
%%_emacs_bytecompile /usr/bin/emacs -batch --no-init-file --no-site-file --eval '(progn (setq load-path (cons "." load-path)))' -f batch-byte-compile
EOF

%install
%make_install -C build-gtk

rm -f %{buildroot}%{_bindir}/emacs
rm -f %{buildroot}%{_infodir}/dir

# Remove emacs.pdmp from common
rm -f %{buildroot}%{_libexecdir}/emacs/%{version}/%{_target_platform}/emacs*.pdmp

# remove sun specific stuff
rm -f %{buildroot}%{_datadir}/emacs/%{version}/etc/{emacstool.1,emacs.1,ctags.1,etags.1,sex.6}

# rename ctags to gctags
mv %{buildroot}%{_mandir}/man1/ctags.1.gz %{buildroot}%{_mandir}/man1/gctags.1.gz
mv %{buildroot}%{_bindir}/ctags %{buildroot}%{_bindir}/gctags

mkdir -p %{buildroot}%{_sysconfdir}/emacs
install -p -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/emacs/site-start.el
ln -s %{_sysconfdir}/emacs/site-start.el %{buildroot}%{_datadir}/emacs/%{version}/lisp/site-start.el

install -d %{buildroot}%{_sysconfdir}/emacs/site-start.d

# Install app data
# Upstream ships its own appdata file, but it's quite terse.
rm -rf %{buildroot}%{_metainfodir}/emacs.appdata.xml
install -Dpm644 %{SOURCE10} %{buildroot}%{_metainfodir}/emacs.appdata.xml

# Install rpm macro definition file
mkdir -p %{buildroot}%{_rpmmacrodir}
install -p -m 0644 macros.emacs %{buildroot}%{_rpmmacrodir}/

install -p -m755 build-nox/src/emacs %{buildroot}%{_bindir}/emacs-nox
install -p -m644 build-nox/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-nox.pdmp
install -p -m755 build-pgtk/src/emacs %{buildroot}%{_bindir}/emacs-pgtk
install -p -m644 build-pgtk/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-pgtk.pdmp
mkdir -p %{buildroot}%{_datadir}/glib-2.0/schemas
install -p -m644 etc/org.gnu.emacs.defaults.gschema.xml %{buildroot}%{_datadir}/glib-2.0/schemas
install -p -m644 build-gtk/src/emacs.pdmp %{buildroot}%{_bindir}/emacs-%{version}.pdmp

chmod -t %{buildroot}%{_bindir}/emacs*

# Install a desktop entry for pgtk (Wayland)
install -p -m644 %{SOURCE9} %{buildroot}%{_datadir}/applications/emacs-pgtk.desktop

# Remove duplicate desktop-related files
rm -f %{buildroot}%{_datadir}/%{name}/%{version}/etc/%{name}.{desktop,service}


# create file lists

#
# emacs-doc file list
#
# 3.22MB of docs from emacs-common to emacs-doc to reduce size (tutorials, news, postscript files, ...)
# NB: etc/ps-prin{0,1}.ps are needed by ps-print
find %{buildroot}%{_datadir}/emacs/%{version}/etc/ -type f | \
  grep -E 'TUTORIAL\.|NEWS|ONEWS|.ps$'|fgrep -v /etc/ps-prin | \
  sed "s^%{buildroot}^^" > doc-filelist

#
# emacs-el file list
#

# take every .el and .el.gz which have a corresponding .elc
find %{buildroot}%{_datadir}/emacs -name '*.el' -o -name '*.el.gz' | \
  grep -v /leim/ | while read I; do
  f=`basename $I .gz`
  f=`basename $f .el`
  if [ -e `dirname $I`/$f.elc ]; then
    echo $I | sed "s^%{buildroot}^^"
  fi
done > el-filelist

#
# emacs-common file list
#

# everything not in previous filelists, and remove a few things listed in %%files
find %{buildroot}%{_datadir}/emacs/%{version} -type f -print -o -type d -printf "%%%%dir %%p\n" | \
  grep -v /leim/ | sed "s^%{buildroot}^^" > common-filelist.raw
while read I; do
  grep -qxF $I doc-filelist el-filelist || echo $I
done < common-filelist.raw > common-filelist

find %{buildroot}%{_libexecdir}/emacs -type f -print -o -type d -printf "%%%%dir %%p\n" | \
  grep -E -v 'movemail$|update-game-score$' | sed "s^%{buildroot}^^" >> common-filelist

# this conflicts with the info package
rm -f %{buildroot}%{_infodir}/info.info.gz

%define info_files  auth autotype bovine calc ccmode cl dbus dired-x ebrowse ede ediff edt efaq eglot eieio eintr elisp emacs emacs-gnutls emacs-mime epa erc ert eshell eudc eww flymake forms gnus htmlfontify idlwave ido mairix-el message mh-e modus-themes newsticker nxml-mode octave-mode org pcl-cvs pgg rcirc reftex remember sasl sc semantic ses sieve smtpmail speedbar srecode todo-mode tramp transient url use-package vhdl-mode vip viper vtable widget wisent woman
have_info_files=$(echo $(ls %{buildroot}%{_infodir} | sed -e 's/\.info\.gz$//' | grep -E -v -- '-[0-9]+$' | LC_ALL=C sort))

[ "$have_info_files" = "%info_files" ] || {
  echo "you must modify the spec file, %%info_files should be: $have_info_files"
  exit 1
}


%post nox
update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-nox 10

[[ ! -f %{_bindir}/emacs ]] && update-alternatives --auto emacs
:

%postun nox
[[ ! -f %{_bindir}/emacs-nox ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-nox
:

%post
/usr/sbin/update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-%{version} 21

%postun
[[ ! -f %{_bindir}/emacs-%{version} ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-%{version}|| :

%post pgtk
update-alternatives --install %{_bindir}/emacs emacs %{_bindir}/emacs-pgtk 11

[[ ! -f %{_bindir}/emacs ]] && update-alternatives --auto emacs
:

%postun pgtk
[[ ! -f %{_bindir}/emacs-pgtk ]] && \
    /usr/sbin/update-alternatives --remove emacs %{_bindir}/emacs-pgtk
:

%files -f common-filelist common
%{_rpmmacrodir}/macros.emacs
%doc BUGS README src/COPYING
%dir %{_sysconfdir}/emacs/site-start.d
%dir %{_sysconfdir}/emacs
%config(noreplace) %{_sysconfdir}/emacs/site-start.el
%dir %{_datadir}/emacs
%dir %{_datadir}/emacs/site-lisp
%{_datadir}/emacs/%{version}/lisp/site-start.el
%attr(2755,root,mail) %{_libexecdir}/emacs/%{version}/%{_target_platform}/movemail
%{_bindir}/emacsclient
%{_bindir}/etags
%{_bindir}/ebrowse
%{_bindir}/gctags
%{_mandir}/*/*
%{_includedir}/emacs-module.h
%{_infodir}/*
%{_userunitdir}/emacs.service
%{_datadir}/applications/emacsclient.desktop
%{_datadir}/applications/emacsclient-mail.desktop
%{_datadir}/applications/emacs-mail.desktop
%{_iconsdir}/hicolor/*/apps/emacs*.png
%{_iconsdir}/hicolor/scalable/apps/emacs.svg
%{_iconsdir}/hicolor/scalable/mimetypes/emacs-document.svg
%{_iconsdir}/hicolor/scalable/mimetypes/emacs-document23.svg
%{_iconsdir}/hicolor/scalable/apps/emacs.ico
%{_metainfodir}/emacs.metainfo.xml
%{_metainfodir}/emacs.appdata.xml

%files -f doc-filelist doc

%files -f el-filelist el
%doc src/COPYING
%{_datadir}/emacs/%{version}/site-lisp/subdirs.el
%{_datadir}/emacs/site-lisp/subdirs.el
%{_datadir}/emacs/%{version}/lisp/leim/ja-dic/*.el.gz
%{_datadir}/emacs/%{version}/lisp/leim/quail/*.el.gz

%files leim
%doc src/COPYING
%{_datadir}/emacs/%{version}/lisp/leim/leim-list.el
%dir %{_datadir}/emacs/%{version}/lisp/leim/ja-dic
%{_datadir}/emacs/%{version}/lisp/leim/ja-dic/*.elc
%dir %{_datadir}/emacs/%{version}/lisp/leim/quail
%{_datadir}/emacs/%{version}/lisp/leim/quail/*.elc

%files nox
%doc src/COPYING
%{_bindir}/emacs-nox
%{_bindir}/emacs-nox.pdmp

%files pgtk
%doc src/COPYING
%{_bindir}/emacs-pgtk
%{_bindir}/emacs-pgtk.pdmp
%{_datadir}/applications/emacs-pgtk.desktop
%{_datadir}/glib-2.0/schemas/org.gnu.emacs.defaults.gschema.xml

%files
%doc src/COPYING
%{_bindir}/emacs-%{version}
%{_bindir}/emacs-%{version}.pdmp
%{_datadir}/applications/emacs.desktop


%changelog
* Sat Oct 05 2024 kekepower <kekepower> 29.4-5.mga10
+ Revision: 2103415
- Rebuild for new tree-sitter

* Wed Aug 28 2024 daviddavid <daviddavid> 29.4-4.mga10
+ Revision: 2092091
- enable tree-sitter support

* Sat Aug 24 2024 daviddavid <daviddavid> 29.4-3.mga10
+ Revision: 2090492
- move all desktop icons files into the -common sub-pkg
- use a separate desktop file for emacs-pgtk sub-pkg

* Sat Aug 24 2024 daviddavid <daviddavid> 29.4-2.mga10
+ Revision: 2090479
- set text + icons for toolbar style by default (mga#28523)

* Mon Jun 24 2024 ns80 <ns80> 29.4-1.mga10
+ Revision: 2076372
- new version 29.4 to fix an arbitrary shell command evaluation

* Fri May 31 2024 ns80 <ns80> 29.3-3.mga10
+ Revision: 2068896
- add a version of emacs built with Wayland only support (emacs-pgtk)

* Fri Mar 29 2024 ns80 <ns80> 29.3-2.mga10
+ Revision: 2053059
- fix files for i586
- fix for armv7hl

* Thu Mar 28 2024 ns80 <ns80> 29.3-1.mga10
+ Revision: 2052950
- new version 29.3 for CVE-2024-3020[2-5] (mga#33019)

* Tue Apr 11 2023 ns80 <ns80> 28.2-10.mga9
+ Revision: 1952595
- backport upstream patches for CVE-2023-28617 (mga#31767)

* Thu Mar 09 2023 luigiwalser <luigiwalser> 28.2-9.mga9
+ Revision: 1948467
- add upstream patch to fix lisp injection in emacsclient-mail.desktop (CVE-2023-27986)

* Wed Mar 08 2023 luigiwalser <luigiwalser> 28.2-8.mga9
+ Revision: 1948388
- add upstream patch to fix command injection in emacsclient-mail.desktop (CVE-2023-27985)

* Mon Feb 27 2023 ns80 <ns80> 28.2-7.mga9
+ Revision: 1945607
- add patches from Debian for CVE-2023-4833[7-9] (mga#31593)

* Mon Dec 12 2022 ns80 <ns80> 28.2-6.mga9
+ Revision: 1921010
- rebuild for new libtiff

* Fri Dec 02 2022 ns80 <ns80> 28.2-5.mga9
+ Revision: 1914028
- add upstream patch for CVE-2022-45939 (mga#31211)

* Mon Nov 07 2022 wally <wally> 28.2-4.mga9
+ Revision: 1904457
- build against webkit2gtk-4.1

* Mon Nov 07 2022 ghibo <ghibo> 28.2-3.mga9
+ Revision: 1904448
- Add webkit2gtk-4.0 in BuildRequires to fix building.
- Remove sed script to force building against webkit2gtk-4.1 as it doesn't work.

* Tue Sep 20 2022 wally <wally> 28.2-2.mga9
+ Revision: 1890946
- build against webkit2gtk-4.1

* Mon Sep 12 2022 luigiwalser <luigiwalser> 28.2-1.mga9
+ Revision: 1887458
- 28.2

* Mon Apr 04 2022 luigiwalser <luigiwalser> 28.1-1.mga9
+ Revision: 1843894
- 23.1
- remove patches 1, 3, 5 (fixed upstream)

* Tue Mar 29 2022 umeabot <umeabot> 27.2-4.mga9
+ Revision: 1831345
- Mageia 9 Mass Rebuild

* Fri Dec 31 2021 wally <wally> 27.2-3.mga9
+ Revision: 1765604
- provide emacs(bin)

* Sun Jul 04 2021 wally <wally> 27.2-2.mga9
+ Revision: 1734656
- install emacs.appdata.xml to /usr/share/metainfo
- build different flavours in their own build-<flavour> dirs
- drop old obsoletes and conflicts
- update versions in provides

* Sun Jul 04 2021 luigiwalser <luigiwalser> 27.2-1.mga9
+ Revision: 1734614
- 27.2
- add patches from fedora
- build gtk3 version with xwidgets and cairo
- BR webkit2-devel for xwidgets
- BR jansson-devel for json support
- recommend enchant2 for spellchecker patch
- fix broken emacs-nox because of pdmp file (mga#29208)
- use upstream service file

* Wed Sep 30 2020 joequant <joequant> 27.1-1.mga8
+ Revision: 1631350
- update to 27.1

* Sun Aug 30 2020 luigiwalser <luigiwalser> 26.3-6.mga8
+ Revision: 1620088
- fix saveplace syntax in default config (changed in 25.1)

* Wed Aug 19 2020 ovitters <ovitters> 26.3-5.mga8
+ Revision: 1616009
- remove install-info scriptlets, rely on filetrigger instead (mga#27107)

* Mon Aug 10 2020 joequant <joequant> 26.3-4.mga8
+ Revision: 1612892
- patch bug 42676 - segfault on x11

* Sun Jun 28 2020 joequant <joequant> 26.3-3.mga8
+ Revision: 1600059
- add source
- fix system service file to avoid buildroot break

* Sun Feb 16 2020 umeabot <umeabot> 26.3-2.mga8
+ Revision: 1536547
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Fri Oct 18 2019 tv <tv> 26.3-1.mga8
+ Revision: 1454455
- new release

* Fri Apr 12 2019 luigiwalser <luigiwalser> 26.2-1.mga7
+ Revision: 1389505
- 26.2

* Sun Sep 23 2018 umeabot <umeabot> 26.1-2.mga7
+ Revision: 1297589
- Mageia 7 Mass Rebuild

* Mon May 28 2018 tv <tv> 26.1-1.mga7
+ Revision: 1232859
- adjust file list
- new release

* Sun Apr 08 2018 kekepower <kekepower> 25.3-4.mga7
+ Revision: 1216271
- Rebuild for new libotf

* Thu Jan 18 2018 shlomif <shlomif> 25.3-3.mga7
+ Revision: 1194421
- Rebuild for new imagemagick

* Wed Dec 27 2017 wally <wally> 25.3-2.mga7
+ Revision: 1185826
- rebuild for new imagemagick

* Sat Oct 14 2017 zezinho <zezinho> 25.3-1.mga7
+ Revision: 1171795
- new version

* Fri Sep 08 2017 joequant <joequant> 25.1-1.mga7
+ Revision: 1151954
- update to 25.1

* Sat May 27 2017 shlomif <shlomif> 24.5-8.mga6
+ Revision: 1105214
- rebuild for new imagemagick lib-major

* Sat Dec 31 2016 wally <wally> 24.5-7.mga6
+ Revision: 1078831
- fix rpm macros

* Fri Jul 15 2016 eatdirt <eatdirt> 24.5-6.mga6
+ Revision: 1042174
- Fixing missing gtk3 icons (mga#18470)

* Thu Jun 16 2016 tv <tv> 24.5-5.mga6
+ Revision: 1021697
- add emacs macros for rpm

* Fri Feb 12 2016 marja <marja> 24.5-4.mga6
+ Revision: 959287
- re-add conflict, to ensure smooth upgrading
- get rid of some "unversioned-explicit-*" rpmlint warnings
  o add = %%{version}-%%{release} where needed
  o remove obs/prov for emacs-url
- fix macro in comment
- make emacs obsolete xemacs

* Mon Jan 11 2016 luigiwalser <luigiwalser> 24.5-3.mga6
+ Revision: 921801
- rebuild for gnutls

* Thu Jan 07 2016 luigiwalser <luigiwalser> 24.5-2.mga6
+ Revision: 920393
- rebuild for giflib
- add fix from opensuse to fix build with giflib5

* Thu Sep 03 2015 luigiwalser <luigiwalser> 24.5-1.mga6
+ Revision: 872603
- reinstate leim (paths were wrong)
- drop leim subpackage as it is not building with 24.5
- build with acl support
- 24.5
- 24.4
- remove no longer needed patch 1 and patch 6
- rediff patch 100
- remove patch 112 (fixed upstream)
- remove upstream patches 150-153

* Mon Jun 29 2015 tv <tv> 24.3-11.mga6
+ Revision: 847565
- s/old_makeinstall/makeinstall/

* Wed Nov 26 2014 eatdirt <eatdirt> 24.3-10.mga5
+ Revision: 799369
- Fix ispell/hunspell compatibility name when using non-default dictionaries

* Wed Nov 26 2014 eatdirt <eatdirt> 24.3-9.mga5
+ Revision: 799355
- Default dictionnary to hunspell (workaround mga#5439)

* Wed Oct 15 2014 umeabot <umeabot> 24.3-8.mga5
+ Revision: 738965
- Second Mageia 5 Mass Rebuild

* Fri Oct 03 2014 doktor5000 <doktor5000> 24.3-7.mga5
+ Revision: 736407
- added BuildRequires on pkgconfig(librsvg-2.0)
  o fixes broken Help -> About Emacs window (mga#14223)
- added some more BuildRequires to enable other features:
  o pkgconfig(libotf) for OpenType font support
  o pkgconfig(m17n-flt) for text shaping
  o gpm-devel for gpm support in non-x11 version

* Tue Sep 16 2014 umeabot <umeabot> 24.3-6.mga5
+ Revision: 678992
- Mageia 5 Mass Rebuild

* Fri May 30 2014 luigiwalser <luigiwalser> 24.3-5.mga5
+ Revision: 628025
- add patches from fedora to fix CVE-2014-342[1-4]

* Sat Oct 19 2013 umeabot <umeabot> 24.3-4.mga5
+ Revision: 526086
- Mageia 4 Mass Rebuild

* Mon Jun 03 2013 fwang <fwang> 24.3-3.mga4
+ Revision: 435825
- rebuild for new libpng

* Wed May 29 2013 blino <blino> 24.3-2.mga4
+ Revision: 429871
- do not ship info.info (conflicts with info package)

* Tue May 28 2013 blino <blino> 24.3-1.mga4
+ Revision: 429809
- do not package rcs-checkin (removed upstream)
- sync info files list
- drop merged rpath patch
- 24.3

* Tue May 28 2013 fwang <fwang> 24.2-6.mga4
+ Revision: 429149
- rebuild for new imagemagick

* Fri Jan 11 2013 umeabot <umeabot> 24.2-5.mga3
+ Revision: 349596
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 07 2013 luigiwalser <luigiwalser> 24.2-4.mga3
+ Revision: 340533
- fix for changed _libexecdir

* Fri Dec 14 2012 fwang <fwang> 24.2-3.mga3
+ Revision: 330771
- rebuild for new imagemagick

* Fri Oct 12 2012 fwang <fwang> 24.2-2.mga3
+ Revision: 305159
- rebuild for new imagemagick

* Sun Oct 07 2012 luigiwalser <luigiwalser> 24.2-1.mga3
+ Revision: 303174
- 24.2
- remove upstreamed patches 8 and 112
- cosmetic fixes

* Thu Sep 06 2012 luigiwalser <luigiwalser> 24.1-2.mga3
+ Revision: 288887
- add patch from upstream via gentoo to fix compilation with glibc 2.16
- add patch from fedora to fix CVE-2012-3479

* Sun Jun 10 2012 blino <blino> 24.1-1.mga3
+ Revision: 259558
- build with gtk3 instead of gtk2
- remove deprecated b2m (Babyl to mbox)
- update info file list
- adapt to info files being gzipped by upstream build
- no need to manually remove fakemail, not upstream anymore
- explicitely buildrequire imagemagick devel for imagemagick support
- explicitely buildrequire gnutls devel for gnutls support
- explicitely buildrequire libxml2-devel for xml support
- fix autoreconf by using m4 dir
- drop unused xaw3d from requires
- drop ia64 patch, which seems to add a conflicting function prototype
- drop merged patches
- drop merged string format patch
- remove lzma patch, upstream now supports xz info pages (we only have a few remaining packages using lzma info pages, they should be rebuild to use xz)
- drop unmaintained ppc/ppc64 patches (seems to be handled upstream anyway, with macppc and powerpc64 archs)
- rediff ispell patch
- drop toolbar hide patch, keep upstream default
- drop x86_64 patch, this arch is handled in configure as amdx86-64
- drop sendmail patch, emacs now defaults to sendmail as well (instead of fakemail previously)
- remove bzip2 patch, emacs now supports compressed info pages (this is even the default)
- rediff rpath patch
- 24.1

* Thu Apr 12 2012 blino <blino> 23.3-8.mga2
+ Revision: 230325
- adapt to svn 1.7 change, with no .svn directory in each sub directory (patch from upstream)
+ malo <malo>
- Change emacs-config to use enchant by default (Bug #4462)

* Mon Feb 13 2012 dmorgan <dmorgan> 23.3-6.mga2
+ Revision: 208353
- Fix buildrequires

* Sat Jan 28 2012 malo <malo> 23.3-5.mga2
+ Revision: 202643
- bump rel
- added missing %%postun (that was preventing correct alternative upgrade, #3201)

* Fri Dec 23 2011 fwang <fwang> 23.3-4.mga2
+ Revision: 186506
- rebuild for new libtiff

* Fri Nov 11 2011 blino <blino> 23.3-3.mga2
+ Revision: 166533
- fix infinite loop in text mode select() when built with gtk support
  this has been exposed by glib >= 2.31 (emacs #9754, mga #3259)

* Mon Sep 19 2011 fwang <fwang> 23.3-2.mga2
+ Revision: 145302
- rebuild for new libpng

* Thu Sep 08 2011 tv <tv> 23.3-1.mga2
+ Revision: 141574
- new release
- rediff patch 100
- drop patch 117 (fixed other way upstream)

* Fri Sep 02 2011 tv <tv> 23.2-4.mga2
+ Revision: 137802
- make the somewhat huge el subpackage be noarch

* Thu Jan 13 2011 ahmad <ahmad> 23.2-3.mga1
+ Revision: 8303
- adapt emacs-23.1.92-version.patch and emacs-config to the distro changes
- drop old/unneeded scriptlets
- imported package emacs

